* ===================================================================
* Date: Mar 2024
* Paper: House Satisfaction and Social Comparison
* Data: University of Essex, Institute for Social and Economic Research. (2021). British Household Panel Survey: Waves 1-18, 1991-2009. [data collection]. 8th Edition. UK Data Service. SN: 5151, DOI: http://doi.org/10.5255/UKDA-SN-5151-2.
* ===================================================================

clear all

global date = "20221107"

do RevDataprep.do

* define macros
global woff = 25
global boff = 75
do lowandhigh.do
global demography age1-age5 edu1 edu2 socioeco1-socioeco3 i.jobstatus_cat numkids kid_born type2 type3 type4  
global objective mortgage move hstype2-hstype5 garden central damp rot i.talkneigh pollution crime 

*----------------------------------------------------------------------------------------
* Table 6/7/R1/A1/A2/A3: Robustness check - self comparison based on home values and income
* Table 6: Alternative social comparison index calculation methods
* Table 7: Alternative self-comparison measurements
* Table R1: Models with and without self-comparison, and with different social comparison index construction methods
* A1. Baseline model without self-comparison
* A2. Baseline model with self-comparison (loss/gain dummies: inclossd & vallossd)
* A3. Baseline model with self-comparison (loss/gain truncated variables: incloss & valloss)
*----------------------------------------------------------------------------------------

capture erase hautest.txt
capture erase R4adptest.txt

* Table A1 - original model without self-comparison
global subjective fin finfine space neighnoi streetnoi nincome nvalue  
global title = "1"
do lossaversion.do

esttab using Table_R1_$date.rtf, re stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A1 - original model without self-comparison) not

* Table A2 - self-comparison (dummy variable apporach)
global subjective fin finfine space neighnoi streetnoi nincome nvalue inclossd vallossd
global title = "2"
do lossaversion.do

esttab using Table_R1_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A2 - self-comparison dummy variable apporach) not

* Table 6 - adaptation part
eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd1 high_wd1
do adaptationtest.do

esttab using Table_6_$date.rtf, re stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 6 - SC1 Adaptation Test) not	

eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd2 high_wd2
do adaptationtest.do

esttab using Table_6_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 6 - SC2 Adaptation Test) not
	
eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd3 high_wd3
do adaptationtest.do

esttab using Table_6_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 6 - SC3 Adaptation Test) not

eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd4 high_wd4
do adaptationtest.do

esttab using Table_6_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 6 - SC4 Adaptation Test) not
	
* Table A3 - self-comparison (truncated variable apporach)
global subjective fin finfine space neighnoi streetnoi nincome nvalue incloss valloss
global title = "3"
do lossaversion.do

esttab using Table_R1_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A3 - self-comparison truncated variable apporach) not
	
*---------------------------------------------------------------------------------------------------
* Table 8/R2/R4/A4/A5/A6/A7: Robustness check - transformation of continues variables
* Table 8: Robustness check - transformation of continues variables
* R2: Alternative transformations of continuous variables
* R4: Adaptation test up to lag 5
* A4. Baseline model with self-comparison (loss/gain dummies: inclossd & vallossd) - natural log transformation
* A5. Baseline model with self-comparison (loss/gain dummies: inclossd & vallossd) - normalisation approach
* A6. Baseline model with self-comparison (loss/gain dummies: inclossd & vallossd) - quadratic transformation
* A7. Baseline model with self-comparison (loss/gain dummies: inclossd & vallossd) - no transformation
*----------------------------------------------------------------------------------------

capture erase hautest.txt
capture erase R4adptest.txt
global lagvar = "5" 

* log transformation
global subjective fin finfine space neighnoi streetnoi lincome lval inclossd vallossd
global title = "4"
do lossaversion.do

esttab using Table_R2_$date.rtf, re stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A4 - natural log transformation) not

eststo clear
global subjective fin finfine space neighnoi streetnoi lincome inclossd vallossd
global regname lval
do adaptationtest.do
global regname lval low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, re stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 8 - log transformation) not	

* normalisation (dummy variables)
global subjective fin finfine space neighnoi streetnoi nincome nvalue inclossd vallossd
global title = "5"
do lossaversion.do

esttab using Table_R2_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A5 - normalisation dummy variables) not	

eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 8 - normalisation dummy variables) not	

* no transformation
global subjective fin finfine space neighnoi streetnoi income val0 inclossd vallossd
global title = "6"
do lossaversion.do

esttab using Table_R2_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A6 - no transformation) not	

eststo clear
global subjective fin finfine space neighnoi streetnoi income inclossd vallossd
global regname val0
do adaptationtest.do
global regname val0 low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 8 - no transformation) not	
	
* quadratic transformation
global subjective fin finfine space neighnoi streetnoi income income2 val0 val02 inclossd vallossd
global title = "7"
do lossaversion.do

esttab using Table_R2_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A7 - quadratic transformation) not	

eststo clear
global subjective fin finfine space neighnoi streetnoi income income2 val02 inclossd vallossd
global regname val0
do adaptationtest.do
global regname val0 low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 8 - quadratic transformation) not	

* normalisation (truncated variables) 
global subjective fin finfine space neighnoi streetnoi nincome nvalue incloss valloss
global title = "8"
do lossaversion.do

esttab using Table_R2_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A8 - normalisation truncated variables) not	

eststo clear
global subjective fin finfine space neighnoi streetnoi nincome incloss valloss
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 7 - normalisation truncated variables) not
	
*----------------------------------------------------------------------------------------
* Table R3/9/A8: Alternative definition of inequality/better-off/worse-off/worse-off
* Table 9: Alternative definition of inequality/better-off/worse-off/worse-off
* In the main analysis, housing wealth distribution is assumed to be equal, with 25% better-off and 25% worse-off. 
* Seven senarios are considered with different definition of HIGH and LOW dummies (percentage of low, medium, high). 
* Scenario 1: 25% 	50% 25% (baseline)
* Scenario 2: 30% 	50% 20% (inequality 1)
* Scenario 3: 40%	40%	20% (inequality 2)
* Scenario 4: 50%	40%	10% (inequality 3)
* Scenario 5: 20%	55%	25% (equality 1)
* Scenario 6: 15%	60%	25% (equality 2)
* Scenario 7: 10%	65%	25% (equality 3)
*----------------------------------------------------------------------------------------	

capture erease Table_R3_$date.rtf
capture erease Table_9_$date.rtf
capture erase hautest.txt
capture erase R4adptest.txt
global lagvar = "5" 

matrix cut = (25,75 \ 30,80 \ 40,80 \ 50,90 \ 20,75 \ 15,75 \ 10,75)

global demography age1-age5 edu1 edu2 socioeco1-socioeco3 i.jobstatus_cat numkids kid_born type2 type3 type4  
global objective mortgage move hstype2-hstype5 garden central damp rot i.talkneigh pollution crime 

forvalues i = 1/7{
	global woff = cut[`i',1]
	global boff = cut[`i',2]
	do lowandhigh.do
	global subjective fin finfine space neighnoi streetnoi nincome nvalue inclossd vallossd	
	global title = "`i'"
	eststo clear
	do lossaversion.do

esttab using Table_R3_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table A8 - Scenario`i') not
	
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
eststo clear
do adaptationtest.do
global regname nvalue low_wd2 high_wd2
do adaptationtest.do

esttab using Table_9_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) ///
	varwidth(25) modelwidth(7) b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant ///
	compress drop(*.region *.wave) title(Table 9 - Scenario`i') not
}

*----------------------------------------------------------------------------------------
* Table R5/9/A9/A10/A11: Robustness check - Fin Finfine removed and IV Panel regression
* A9. Mainfinding without Fin & Finfine
* A10. IV panel regression with yearresid (length of resdientce in current house)
* A11. IV panel regression with regm (median house value in the same region)
* IV analysis
* The Sargan-Hansen test is a test of overidentifying restrictions.  The joint null hypothesis is that the instruments are valid instruments, i.e.,
* uncorrelated with the error term, and that the excluded instruments are correctly excluded from the estimated equation.
* Underidentification test (Kleibergen-Paap rk LM statistic): H0 the model is underundentified
* Weak identification test (Cragg-Donald Wald F statistic & Kleibergen-Paap rk Wald F statistic): H0 the model is weekly underundentified    
*----------------------------------------------------------------------------------------

capture erase hautest.txt
capture erase R4adptest.txt
global woff = 25
global boff = 75
do lowandhigh.do
global demography age1-age5 edu1 edu2 socioeco1-socioeco3 i.jobstatus_cat numkids kid_born type2 type3 type4  
global objective mortgage move hstype2-hstype5 garden central damp rot i.talkneigh pollution crime 

* Table A9 - Mainfinding without Fin & Finfine
global subjective space neighnoi streetnoi nincome nvalue inclossd vallossd
global title = "1"
do SC2only.do

esttab using Table_R5_$date.rtf, re /// 
	stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f))  b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) ///
	varwidth(25) modelwidth(7) label onecell nogaps nobaselevels noconstant compress ///
	drop(*.region *.wave) ///
	title(Table A9 - Main Finding without Fin & Finfine) not
	
eststo clear
global subjective space neighnoi streetnoi nincome inclossd vallossd
global regname nvalue
do adaptationtest.do
global regname nvalue low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, re stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 9 - Main Finding without Fin & Finfine) not	

* Table A10 - IV panel regression with refm (average house price of reference group - edu age and socioecon only)
capture drop refm reft refn	
bysort wave edutemp agetemp socioeco_new: egen reft = total(nvalue)
bysort wave edutemp agetemp socioeco_new: egen refn = count(nvalue)
gen refm = (reft-nvalue)/refn
sort pid wave

global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global title = "2"

eststo clear
xtreg nvalue refm $demography $objective $subjective i.region i.wave low_wd2 high_wd2, fe vce(cluster hhid_new)
capture drop nvaluehat
predict nvaluehat, xb

eststo: xtivreg housat (nvalue = refm) $demography $objective $subjective i.region i.wave low_wd2 high_wd2, fe vce(cluster hhid_new)
global rnames nvaluehat low_wd2 high_wd2
do hautest.do

esttab using Table_R5_$date.rtf, append /// 
	stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f))  b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) ///
	varwidth(25) modelwidth(7) label onecell nogaps nobaselevels noconstant compress ///
	drop(*.region *.wave) ///
	title(Table A10 - IV panel regression with refm - median house price of reference group) not
	
eststo clear
global subjective fin finfine space neighnoi streetnoi nincome inclossd vallossd
global regname nvaluehat
do adaptationtest.do
global regname nvaluehat low_wd2 high_wd2
do adaptationtest.do

esttab using Table_R4_$date.rtf, append stats(N r2_w r2_b r2_o F p, fmt(%9.0g %10.6f)) varwidth(25) modelwidth(7) ///
	b(%10.4f) star(* 0.10 ** 0.05 *** 0.01) label onecell nogaps nobaselevels noconstant compress drop(*.region *.wave) ///
	title(Table 9 - IV panel regression with refm) not	


