*---------------------------------------------------------------------
* Model 1: socio-economic groups only
* Model 2: education groups only
* Model 3: age groups only
* Model 4: region groups only
* Model 5: socio-economic, education, age, and region groups in one model
* Model 6: SC index version 1 (see below)
* Model 7: SC index version 2 (see below)
* Model 8: SC index version 3 (see below)

* Social comparison index calculation: Three weighting methods
* 1. Based on the loss aversion coefficient estimated in Model 1 through Model 2 (original submission version)
* 2. Based on the loss/gain coefficient estimates in Model 5 (suggested by reviewer 1)
* 3. Based on the loss/gain coefficient estimates in Model 1 through Model 4 (alternative of No.2)
* 4. Based on the loss/gain coefficient estimates in Model 5, sig coefs only (suggested by reviewer 1)
*----------------------------------------------------------------------------------------

eststo clear
capture drop low_w* high_w*

*[1] social comparison variables = socio-economic groups ;
eststo m1: qui xtreg housat $demography $objective $subjective i.region i.wave selowd sehighd, fe vce(cluster hhid_new)  
local lowe1=_b[selowd]
local high1=_b[sehighd]
global rnames selowd sehighd
do hautest.do


*[2] social comparison variables = edu ;
eststo m2: qui xtreg housat $demography $objective $subjective i.region i.wave edulowd eduhighd, fe vce(cluster hhid_new)  
local lowe2=_b[edulowd]
local high2=_b[eduhighd]
global rnames edulowd eduhighd
do hautest.do
			 
*[3] social comparison variables = age ;
eststo m3: qui xtreg housat $demography $objective $subjective i.region i.wave agelowd agehighd, fe vce(cluster hhid_new)  
local lowe3=_b[agelowd]
local high3=_b[agehighd]
global rnames agelowd agehighd
do hautest.do

	
*[4] social comparison variables = region ;
eststo m4: qui xtreg housat $demography $objective $subjective i.region i.wave reglowd reghighd, fe vce(cluster hhid_new)  
local lowe4=_b[reglowd]
local high4=_b[reghighd]
global rnames reglowd reghighd
do hautest.do

matrix low2 = (abs(`lowe1'),abs(`lowe2'),abs(`lowe3'),abs(`lowe4'))/(abs(`lowe1')+abs(`lowe2')+abs(`lowe3')+abs(`lowe4'))
matrix high2 = (abs(`high1'),abs(`high2'),abs(`high3'),abs(`high4'))/(abs(`high1')+abs(`high2')+abs(`high3')+abs(`high4'))

*[5] social comparison variables = all;
eststo m5: qui xtreg housat $demography $objective $subjective i.region i.wave ///
			selowd sehighd edulowd eduhighd agelowd agehighd reglowd reghighd, fe vce(cluster hhid_new)  
matrix low1=(abs(_b[selowd]), abs(_b[edulowd]),abs(_b[agelowd]),abs(_b[reglowd]))/(abs(_b[selowd])+abs(_b[edulowd])+abs(_b[agelowd])+abs(_b[reglowd]))
matrix high1=(abs(_b[sehighd]),abs(_b[eduhighd]),abs(_b[agehighd]),abs(_b[reghighd]))/(abs(_b[sehighd])+abs(_b[eduhighd])+abs(_b[agehighd])+abs(_b[reghighd]))

global rnames selowd sehighd edulowd eduhighd agelowd agehighd reglowd reghighd
do hautest.do				
			
*[6] social comparison variables = SC Index 1 (original weighting, using seperate models);			
local tlambda = abs(`lowe1'/`high1')+abs(`lowe2'/`high2')+abs(`lowe3'/`high3')+abs(`lowe4'/`high4')

gen low_w1 = (abs(`lowe1'/`high1')/`tlambda')*selowd+(abs(`lowe2'/`high2')/`tlambda')*edulowd+(abs(`lowe3'/`high3')/`tlambda')*agelowd+(abs(`lowe4'/`high4')/`tlambda')*reglowd
gen high_w1 = (abs(`lowe1'/`high1')/`tlambda')*sehighd+(abs(`lowe2'/`high2')/`tlambda')*eduhighd+(abs(`lowe3'/`high3')/`tlambda')*agehighd+(abs(`lowe4'/`high4')/`tlambda')*reghighd
gen high_wd1 = (high_w > 0.5)
gen low_wd1 = (low_w > 0.5) 

eststo m6: qui xtreg housat $demography $objective $subjective i.region i.wave low_wd1 high_wd1, fe vce(cluster hhid_new)  	
global rnames low_wd1 high_wd1
do hautest.do

*[7] social comparison variables = SC Index 2 (reviewer request, using Model 5 only, no lambda, all categories);			
gen low_w2 = low1[1,1]*selowd+low1[1,2]*edulowd+low1[1,3]*agelowd+low1[1,4]*reglowd
gen high_w2 = high1[1,1]*sehighd+high1[1,2]*eduhighd+high1[1,3]*agehighd+high1[1,4]*reghighd
gen high_wd2 = (high_w2 > 0.5)
gen low_wd2 = (low_w2 > 0.5) 
eststo m7: qui xtreg housat $demography $objective $subjective i.region i.wave low_wd2 high_wd2, fe vce(cluster hhid_new)  	
global rnames low_wd2 high_wd2
do hautest.do

*[8] social comparison variables = SC Index 2 (reviewer request adjusted, weights from Model 5, coefs from Model 1-4, no lambda);	
gen low_w3 = low2[1,1]*selowd+low2[1,2]*edulowd+low2[1,3]*agelowd+low2[1,4]*reglowd
gen high_w3 = high2[1,1]*sehighd+high2[1,2]*eduhighd+high2[1,3]*agehighd+high2[1,4]*reghighd
gen high_wd3 = (high_w3 > 0.5)
gen low_wd3 = (low_w3 > 0.5) 
eststo m8: qui xtreg housat $demography $objective $subjective i.region i.wave low_wd3 high_wd3, fe vce(cluster hhid_new)  	
global rnames low_wd3 high_wd3
do hautest.do

*[9] social comparison variables = SC Index 2 (reviewer request, using Model 5 only, no lambda, significant categories only);			
gen low_w4 = low1[1,1]*selowd+low1[1,3]*agelowd+low1[1,4]*reglowd
gen high_w4 = reghighd
gen high_wd4 = (high_w4 > 0.5)
gen low_wd4 = (low_w4 > 0.5) 
eststo m9: qui xtreg housat $demography $objective $subjective i.region i.wave low_wd4 high_wd4, fe vce(cluster hhid_new)  	
global rnames low_wd3 high_wd3
do hautest.do

